#testresult{position:absolute;top:19px;right:10px;text-align:right;font-weight:bold;}
.core-test{font:13px/16px "Helvetica",Verdana,Arial,sans-serif;margin:0;padding:0;position:absolute;top:0;left:0;right:0;bottom:0;background-color:#f0f0f0;overflow:auto;}
.core-test .useragent{border-bottom:1px solid #000;font:11px/21px "Helvetica",Verdana,Arial,sans-serif;height:20px;padding:0 8px;}
.core-test ul.detail{list-style-type:none;padding:0;margin:0;background-color:white;top:24px;position:relative;}
.core-test ul.detail ul{margin:0;padding:0;margin-left:20px;position:relative;}.core-test ul.detail li{line-height:24px;list-style-type:none;}
.core-test ul.detail li.plan{margin:4px 0;margin-left:-20px;padding-bottom:4px;border-bottom:1px #ccc solid;}
.core-test ul.detail li.plan>.name{display:none;}.core-test ul.detail li.module>.name{display:block;background-color:#323453;padding:0 4px;color:white;font-weight:bold;margin:2px 0;}
.core-test ul.detail li.test>.name{display:block;font-weight:bold;}.core-test ul.detail li.test.passed>.name{color:#888;}
.core-test ul.detail li.test>.status{display:block;position:absolute;right:0;top:0;}
.core-test ul.detail li.test.passed>.status{display:none;}.core-test ul.detail li.test>.status span{display:inline-block;min-width:14px;text-align:center;padding:0 4px;}
.core-test ul.detail li.assertion{position:relative;}.core-test ul.detail li.assertion>.name{display:block;margin-right:90px;}
.core-test ul.detail li.assertion>.status{display:block;position:absolute;right:0;top:0;padding:0 4px;margin-left:8px;width:80px;background:#ccc;text-transform:uppercase;}
.core-test ul.detail li.assertion{margin:2px 0;}.core-test ul.detail li.assertion.passed{color:#888;margin:2px 0;}
.core-test ul.detail li.assertion.passed .status{background:#bbe9b5;}.core-test ul.detail li.test>.status .passed,.core-test .final-status>.passed{background:#80D175;}
.core-test ul.detail li.test>.status .failed,.core-test ul.detail li.assertion.failed .status,.core-test .final-status>.failed{background:#ea4d44;}
.core-test ul.detail li.test>.status .errors,.core-test ul.detail li.assertion.errors .status,.core-test .final-status>.errors{background:red;color:#fff;}
.core-test ul.detail li.test>.status .warnings,.core-test ul.detail li.assertion.warnings .status,.core-test .final-status>.warnings{background:#E49723;}
.core-test ul.detail.hide-passed li.passed,.core-test ul.detail.hide-passed li.assertion.passed{display:none;}
.core-test .testresult{position:relative;}.core-test label.hide-passed{position:absolute;display:block;left:4px;top:0;line-height:26px;}
.core-test .final-status{display:block;right:4px;position:absolute;top:0;line-height:26px;font-weight:bold;}
.core-test .final-status>span{margin-left:2px;padding:0 3px;}